# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AgentOrchestratorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_provisioning_expiration_at: Optional[str]
    _agent_provisioning_requested_at: Optional[str]
    _agent_provisioning_status: Optional[str]
    _name: str


    def __init__(
        self,
        agent_provisioning_expiration_at: Optional[str] = None,
        agent_provisioning_requested_at: Optional[str] = None,
        agent_provisioning_status: Optional[str] = None,
        name: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_provisioning_expiration_at(self) -> Optional[str]: ...

    @agent_provisioning_expiration_at.setter
    def agent_provisioning_expiration_at(self, agent_provisioning_expiration_at: Optional[str]) -> None: ...

    @property
    def agent_provisioning_requested_at(self) -> Optional[str]: ...

    @agent_provisioning_requested_at.setter
    def agent_provisioning_requested_at(self, agent_provisioning_requested_at: Optional[str]) -> None: ...

    @property
    def agent_provisioning_status(self) -> Optional[str]: ...

    @agent_provisioning_status.setter
    def agent_provisioning_status(self, agent_provisioning_status: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
