# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaParameterOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _formula: Optional[str]
    _item: Optional[ItemSearchPreviewV1]
    _name: str
    _unbound: Optional[bool]


    def __init__(
        self,
        formula: Optional[str] = None,
        item: Optional[ItemSearchPreviewV1] = None,
        name: Optional[str] = None,
        unbound: Optional[bool] = False,
    ) -> None: ...

    @property
    def formula(self) -> Optional[str]: ...

    @formula.setter
    def formula(self, formula: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ItemSearchPreviewV1]: ...

    @item.setter
    def item(self, item: Optional[ItemSearchPreviewV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def unbound(self) -> Optional[bool]: ...

    @unbound.setter
    def unbound(self, unbound: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
