# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CapsuleV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cursor_key: Optional[Any]
    _end: Optional[Any]
    _id: str
    _is_uncertain: Optional[bool]
    _properties: Optional[List[ScalarPropertyV1]]
    _start: Any


    def __init__(
        self,
        cursor_key: Optional[Any] = None,
        end: Optional[Any] = None,
        id: Optional[str] = None,
        is_uncertain: Optional[bool] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        start: Optional[Any] = None,
    ) -> None: ...

    @property
    def cursor_key(self) -> Optional[Any]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[Any]) -> None: ...

    @property
    def end(self) -> Optional[Any]: ...

    @end.setter
    def end(self, end: Optional[Any]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_uncertain(self) -> Optional[bool]: ...

    @is_uncertain.setter
    def is_uncertain(self, is_uncertain: Optional[bool]) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def start(self) -> Any: ...

    @start.setter
    def start(self, start: Any) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
