# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class StoredTableSearchFailureOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _message_key: str
    _row_id: str
    _search_string: str
    _stored_table_id: str


    def __init__(
        self,
        message_key: Optional[str] = None,
        row_id: Optional[str] = None,
        search_string: Optional[str] = None,
        stored_table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def message_key(self) -> str: ...

    @message_key.setter
    def message_key(self, message_key: str) -> None: ...

    @property
    def row_id(self) -> str: ...

    @row_id.setter
    def row_id(self, row_id: str) -> None: ...

    @property
    def search_string(self) -> str: ...

    @search_string.setter
    def search_string(self, search_string: str) -> None: ...

    @property
    def stored_table_id(self) -> str: ...

    @stored_table_id.setter
    def stored_table_id(self, stored_table_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
