# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ManualRunInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _condition_id: str
    _look_ahead_duration_seconds: Optional[int]
    _lookback_duration_seconds: int
    _table_batch_action: Optional[str]


    def __init__(
        self,
        condition_id: Optional[str] = None,
        look_ahead_duration_seconds: Optional[int] = None,
        lookback_duration_seconds: Optional[int] = None,
        table_batch_action: Optional[str] = None,
    ) -> None: ...

    @property
    def condition_id(self) -> str: ...

    @condition_id.setter
    def condition_id(self, condition_id: str) -> None: ...

    @property
    def look_ahead_duration_seconds(self) -> Optional[int]: ...

    @look_ahead_duration_seconds.setter
    def look_ahead_duration_seconds(self, look_ahead_duration_seconds: Optional[int]) -> None: ...

    @property
    def lookback_duration_seconds(self) -> int: ...

    @lookback_duration_seconds.setter
    def lookback_duration_seconds(self, lookback_duration_seconds: int) -> None: ...

    @property
    def table_batch_action(self) -> Optional[str]: ...

    @table_batch_action.setter
    def table_batch_action(self, table_batch_action: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
