# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentVersionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'production': 'bool',
        'revision': 'CustomAgentRevisionOutputV1',
        'version': 'int'
    }

    attribute_map = {
        'production': 'production',
        'revision': 'revision',
        'version': 'version'
    }

    def __init__(self, production=None, revision=None, version=None):
        """
        CustomAgentVersionOutputV1 - a model defined in Swagger
        """

        self._production = None
        self._revision = None
        self._version = None

        if production is not None:
          self.production = production
        if revision is not None:
          self.revision = revision
        if version is not None:
          self.version = version

    @property
    def production(self):
        """
        Gets the production of this CustomAgentVersionOutputV1.
        Whether this is the production version

        :return: The production of this CustomAgentVersionOutputV1.
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """
        Sets the production of this CustomAgentVersionOutputV1.
        Whether this is the production version

        :param production: The production of this CustomAgentVersionOutputV1.
        :type: bool
        """
        if production is None:
            raise ValueError("Invalid value for `production`, must not be `None`")

        self._production = production

    @property
    def revision(self):
        """
        Gets the revision of this CustomAgentVersionOutputV1.

        :return: The revision of this CustomAgentVersionOutputV1.
        :rtype: CustomAgentRevisionOutputV1
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """
        Sets the revision of this CustomAgentVersionOutputV1.

        :param revision: The revision of this CustomAgentVersionOutputV1.
        :type: CustomAgentRevisionOutputV1
        """
        if revision is None:
            raise ValueError("Invalid value for `revision`, must not be `None`")

        self._revision = revision

    @property
    def version(self):
        """
        Gets the version of this CustomAgentVersionOutputV1.
        The version number

        :return: The version of this CustomAgentVersionOutputV1.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CustomAgentVersionOutputV1.
        The version number

        :param version: The version of this CustomAgentVersionOutputV1.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentVersionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
