# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class IdentityPreviewV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource: Optional[DatasourcePreviewV1]
    _email: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_enabled: Optional[bool]
    _is_organization_group: Optional[bool]
    _is_redacted: Optional[bool]
    _is_remote_group_editable: Optional[bool]
    _name: str
    _organization_group: Optional[bool]
    _remote_group_editable: Optional[bool]
    _translation_key: Optional[str]
    _type: str
    _username: Optional[str]
    _username_readable: Optional[bool]


    def __init__(
        self,
        datasource: Optional[DatasourcePreviewV1] = None,
        email: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_enabled: Optional[bool] = False,
        is_organization_group: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        is_remote_group_editable: Optional[bool] = False,
        name: Optional[str] = None,
        organization_group: Optional[bool] = None,
        remote_group_editable: Optional[bool] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        username: Optional[str] = None,
        username_readable: Optional[bool] = False,
    ) -> None: ...

    @property
    def datasource(self) -> Optional[DatasourcePreviewV1]: ...

    @datasource.setter
    def datasource(self, datasource: Optional[DatasourcePreviewV1]) -> None: ...

    @property
    def email(self) -> Optional[str]: ...

    @email.setter
    def email(self, email: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def is_organization_group(self) -> Optional[bool]: ...

    @is_organization_group.setter
    def is_organization_group(self, is_organization_group: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def is_remote_group_editable(self) -> Optional[bool]: ...

    @is_remote_group_editable.setter
    def is_remote_group_editable(self, is_remote_group_editable: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def organization_group(self) -> Optional[bool]: ...

    @organization_group.setter
    def organization_group(self, organization_group: Optional[bool]) -> None: ...

    @property
    def remote_group_editable(self) -> Optional[bool]: ...

    @remote_group_editable.setter
    def remote_group_editable(self, remote_group_editable: Optional[bool]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def username(self) -> Optional[str]: ...

    @username.setter
    def username(self, username: Optional[str]) -> None: ...

    @property
    def username_readable(self) -> Optional[bool]: ...

    @username_readable.setter
    def username_readable(self, username_readable: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
