# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LabelHierarchyOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _category_id: str
    _category_name: str
    _children: List[LabelHierarchyOutputV1]
    _label_id: str
    _label_name: str


    def __init__(
        self,
        category_id: Optional[str] = None,
        category_name: Optional[str] = None,
        children: Optional[List[LabelHierarchyOutputV1]] = None,
        label_id: Optional[str] = None,
        label_name: Optional[str] = None,
    ) -> None: ...

    @property
    def category_id(self) -> str: ...

    @category_id.setter
    def category_id(self, category_id: str) -> None: ...

    @property
    def category_name(self) -> str: ...

    @category_name.setter
    def category_name(self, category_name: str) -> None: ...

    @property
    def children(self) -> List[LabelHierarchyOutputV1]: ...

    @children.setter
    def children(self, children: List[LabelHierarchyOutputV1]) -> None: ...

    @property
    def label_id(self) -> str: ...

    @label_id.setter
    def label_id(self, label_id: str) -> None: ...

    @property
    def label_name(self) -> str: ...

    @label_name.setter
    def label_name(self, label_name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
